ftlv1

package
v0.480.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 30, 2025 License: Apache-2.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	GetDeploymentContextResponse_DbType_name = map[int32]string{
		0: "DB_TYPE_UNSPECIFIED",
		1: "DB_TYPE_POSTGRES",
		2: "DB_TYPE_MYSQL",
	}
	GetDeploymentContextResponse_DbType_value = map[string]int32{
		"DB_TYPE_UNSPECIFIED": 0,
		"DB_TYPE_POSTGRES":    1,
		"DB_TYPE_MYSQL":       2,
	}
)

Enum value maps for GetDeploymentContextResponse_DbType.

var File_xyz_block_ftl_v1_controller_proto protoreflect.FileDescriptor
var File_xyz_block_ftl_v1_ftl_proto protoreflect.FileDescriptor
var File_xyz_block_ftl_v1_schemaservice_proto protoreflect.FileDescriptor
var File_xyz_block_ftl_v1_verb_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type CallRequest

type CallRequest struct {
	Metadata *Metadata `protobuf:"bytes,1,opt,name=metadata,proto3" json:"metadata,omitempty"`
	Verb     *v1.Ref   `protobuf:"bytes,2,opt,name=verb,proto3" json:"verb,omitempty"`
	Body     []byte    `protobuf:"bytes,3,opt,name=body,proto3" json:"body,omitempty"`
	// contains filtered or unexported fields
}

func (*CallRequest) Descriptor deprecated

func (*CallRequest) Descriptor() ([]byte, []int)

Deprecated: Use CallRequest.ProtoReflect.Descriptor instead.

func (*CallRequest) GetBody

func (x *CallRequest) GetBody() []byte

func (*CallRequest) GetMetadata

func (x *CallRequest) GetMetadata() *Metadata

func (*CallRequest) GetVerb

func (x *CallRequest) GetVerb() *v1.Ref

func (*CallRequest) ProtoMessage

func (*CallRequest) ProtoMessage()

func (*CallRequest) ProtoReflect

func (x *CallRequest) ProtoReflect() protoreflect.Message

func (*CallRequest) Reset

func (x *CallRequest) Reset()

func (*CallRequest) String

func (x *CallRequest) String() string

type CallResponse

type CallResponse struct {

	// Types that are valid to be assigned to Response:
	//
	//	*CallResponse_Body
	//	*CallResponse_Error_
	Response isCallResponse_Response `protobuf_oneof:"response"`
	// contains filtered or unexported fields
}

func (*CallResponse) Descriptor deprecated

func (*CallResponse) Descriptor() ([]byte, []int)

Deprecated: Use CallResponse.ProtoReflect.Descriptor instead.

func (*CallResponse) GetBody

func (x *CallResponse) GetBody() []byte

func (*CallResponse) GetError

func (x *CallResponse) GetError() *CallResponse_Error

func (*CallResponse) GetResponse

func (x *CallResponse) GetResponse() isCallResponse_Response

func (*CallResponse) ProtoMessage

func (*CallResponse) ProtoMessage()

func (*CallResponse) ProtoReflect

func (x *CallResponse) ProtoReflect() protoreflect.Message

func (*CallResponse) Reset

func (x *CallResponse) Reset()

func (*CallResponse) String

func (x *CallResponse) String() string

type CallResponse_Body

type CallResponse_Body struct {
	Body []byte `protobuf:"bytes,1,opt,name=body,proto3,oneof"`
}

type CallResponse_Error

type CallResponse_Error struct {
	Message string  `protobuf:"bytes,1,opt,name=message,proto3" json:"message,omitempty"`
	Stack   *string `protobuf:"bytes,2,opt,name=stack,proto3,oneof" json:"stack,omitempty"` // TODO: Richer error type.
	// contains filtered or unexported fields
}

func (*CallResponse_Error) Descriptor deprecated

func (*CallResponse_Error) Descriptor() ([]byte, []int)

Deprecated: Use CallResponse_Error.ProtoReflect.Descriptor instead.

func (*CallResponse_Error) GetMessage

func (x *CallResponse_Error) GetMessage() string

func (*CallResponse_Error) GetStack

func (x *CallResponse_Error) GetStack() string

func (*CallResponse_Error) ProtoMessage

func (*CallResponse_Error) ProtoMessage()

func (*CallResponse_Error) ProtoReflect

func (x *CallResponse_Error) ProtoReflect() protoreflect.Message

func (*CallResponse_Error) Reset

func (x *CallResponse_Error) Reset()

func (*CallResponse_Error) String

func (x *CallResponse_Error) String() string

type CallResponse_Error_

type CallResponse_Error_ struct {
	Error *CallResponse_Error `protobuf:"bytes,2,opt,name=error,proto3,oneof"`
}

type CommitChangesetRequest added in v0.435.0

type CommitChangesetRequest struct {

	// The changeset key to commit.
	Changeset string `protobuf:"bytes,1,opt,name=changeset,proto3" json:"changeset,omitempty"`
	// contains filtered or unexported fields
}

func (*CommitChangesetRequest) Descriptor deprecated added in v0.435.0

func (*CommitChangesetRequest) Descriptor() ([]byte, []int)

Deprecated: Use CommitChangesetRequest.ProtoReflect.Descriptor instead.

func (*CommitChangesetRequest) GetChangeset added in v0.435.0

func (x *CommitChangesetRequest) GetChangeset() string

func (*CommitChangesetRequest) ProtoMessage added in v0.435.0

func (*CommitChangesetRequest) ProtoMessage()

func (*CommitChangesetRequest) ProtoReflect added in v0.435.0

func (x *CommitChangesetRequest) ProtoReflect() protoreflect.Message

func (*CommitChangesetRequest) Reset added in v0.435.0

func (x *CommitChangesetRequest) Reset()

func (*CommitChangesetRequest) String added in v0.435.0

func (x *CommitChangesetRequest) String() string

type CommitChangesetResponse added in v0.435.0

type CommitChangesetResponse struct {
	Changeset *v1.Changeset `protobuf:"bytes,1,opt,name=changeset,proto3" json:"changeset,omitempty"`
	// contains filtered or unexported fields
}

func (*CommitChangesetResponse) Descriptor deprecated added in v0.435.0

func (*CommitChangesetResponse) Descriptor() ([]byte, []int)

Deprecated: Use CommitChangesetResponse.ProtoReflect.Descriptor instead.

func (*CommitChangesetResponse) GetChangeset added in v0.436.0

func (x *CommitChangesetResponse) GetChangeset() *v1.Changeset

func (*CommitChangesetResponse) ProtoMessage added in v0.435.0

func (*CommitChangesetResponse) ProtoMessage()

func (*CommitChangesetResponse) ProtoReflect added in v0.435.0

func (x *CommitChangesetResponse) ProtoReflect() protoreflect.Message

func (*CommitChangesetResponse) Reset added in v0.435.0

func (x *CommitChangesetResponse) Reset()

func (*CommitChangesetResponse) String added in v0.435.0

func (x *CommitChangesetResponse) String() string

type CreateChangesetRequest added in v0.435.0

type CreateChangesetRequest struct {
	RealmChanges []*RealmChange `protobuf:"bytes,1,rep,name=realm_changes,json=realmChanges,proto3" json:"realm_changes,omitempty"`
	// contains filtered or unexported fields
}

func (*CreateChangesetRequest) Descriptor deprecated added in v0.435.0

func (*CreateChangesetRequest) Descriptor() ([]byte, []int)

Deprecated: Use CreateChangesetRequest.ProtoReflect.Descriptor instead.

func (*CreateChangesetRequest) GetRealmChanges added in v0.477.0

func (x *CreateChangesetRequest) GetRealmChanges() []*RealmChange

func (*CreateChangesetRequest) ProtoMessage added in v0.435.0

func (*CreateChangesetRequest) ProtoMessage()

func (*CreateChangesetRequest) ProtoReflect added in v0.435.0

func (x *CreateChangesetRequest) ProtoReflect() protoreflect.Message

func (*CreateChangesetRequest) Reset added in v0.435.0

func (x *CreateChangesetRequest) Reset()

func (*CreateChangesetRequest) String added in v0.435.0

func (x *CreateChangesetRequest) String() string

type CreateChangesetResponse added in v0.435.0

type CreateChangesetResponse struct {

	// The changeset key of the newly created changeset.
	Changeset string `protobuf:"bytes,1,opt,name=changeset,proto3" json:"changeset,omitempty"`
	// contains filtered or unexported fields
}

func (*CreateChangesetResponse) Descriptor deprecated added in v0.435.0

func (*CreateChangesetResponse) Descriptor() ([]byte, []int)

Deprecated: Use CreateChangesetResponse.ProtoReflect.Descriptor instead.

func (*CreateChangesetResponse) GetChangeset added in v0.435.0

func (x *CreateChangesetResponse) GetChangeset() string

func (*CreateChangesetResponse) ProtoMessage added in v0.435.0

func (*CreateChangesetResponse) ProtoMessage()

func (*CreateChangesetResponse) ProtoReflect added in v0.435.0

func (x *CreateChangesetResponse) ProtoReflect() protoreflect.Message

func (*CreateChangesetResponse) Reset added in v0.435.0

func (x *CreateChangesetResponse) Reset()

func (*CreateChangesetResponse) String added in v0.435.0

func (x *CreateChangesetResponse) String() string

type DeployedSchema added in v0.434.0

type DeployedSchema struct {
	DeploymentKey string     `protobuf:"bytes,1,opt,name=deployment_key,json=deploymentKey,proto3" json:"deployment_key,omitempty"`
	Schema        *v1.Module `protobuf:"bytes,2,opt,name=schema,proto3" json:"schema,omitempty"`
	IsActive      bool       `protobuf:"varint,3,opt,name=is_active,json=isActive,proto3" json:"is_active,omitempty"`
	// contains filtered or unexported fields
}

func (*DeployedSchema) Descriptor deprecated added in v0.434.0

func (*DeployedSchema) Descriptor() ([]byte, []int)

Deprecated: Use DeployedSchema.ProtoReflect.Descriptor instead.

func (*DeployedSchema) GetDeploymentKey added in v0.434.0

func (x *DeployedSchema) GetDeploymentKey() string

func (*DeployedSchema) GetIsActive added in v0.434.0

func (x *DeployedSchema) GetIsActive() bool

func (*DeployedSchema) GetSchema added in v0.434.0

func (x *DeployedSchema) GetSchema() *v1.Module

func (*DeployedSchema) ProtoMessage added in v0.434.0

func (*DeployedSchema) ProtoMessage()

func (*DeployedSchema) ProtoReflect added in v0.434.0

func (x *DeployedSchema) ProtoReflect() protoreflect.Message

func (*DeployedSchema) Reset added in v0.434.0

func (x *DeployedSchema) Reset()

func (*DeployedSchema) String added in v0.434.0

func (x *DeployedSchema) String() string

type DrainChangesetRequest added in v0.436.0

type DrainChangesetRequest struct {

	// The changeset key to commit.
	Changeset string `protobuf:"bytes,1,opt,name=changeset,proto3" json:"changeset,omitempty"`
	// contains filtered or unexported fields
}

func (*DrainChangesetRequest) Descriptor deprecated added in v0.436.0

func (*DrainChangesetRequest) Descriptor() ([]byte, []int)

Deprecated: Use DrainChangesetRequest.ProtoReflect.Descriptor instead.

func (*DrainChangesetRequest) GetChangeset added in v0.436.0

func (x *DrainChangesetRequest) GetChangeset() string

func (*DrainChangesetRequest) ProtoMessage added in v0.436.0

func (*DrainChangesetRequest) ProtoMessage()

func (*DrainChangesetRequest) ProtoReflect added in v0.436.0

func (x *DrainChangesetRequest) ProtoReflect() protoreflect.Message

func (*DrainChangesetRequest) Reset added in v0.436.0

func (x *DrainChangesetRequest) Reset()

func (*DrainChangesetRequest) String added in v0.436.0

func (x *DrainChangesetRequest) String() string

type DrainChangesetResponse added in v0.436.0

type DrainChangesetResponse struct {
	// contains filtered or unexported fields
}

func (*DrainChangesetResponse) Descriptor deprecated added in v0.436.0

func (*DrainChangesetResponse) Descriptor() ([]byte, []int)

Deprecated: Use DrainChangesetResponse.ProtoReflect.Descriptor instead.

func (*DrainChangesetResponse) ProtoMessage added in v0.436.0

func (*DrainChangesetResponse) ProtoMessage()

func (*DrainChangesetResponse) ProtoReflect added in v0.436.0

func (x *DrainChangesetResponse) ProtoReflect() protoreflect.Message

func (*DrainChangesetResponse) Reset added in v0.436.0

func (x *DrainChangesetResponse) Reset()

func (*DrainChangesetResponse) String added in v0.436.0

func (x *DrainChangesetResponse) String() string

type FailChangesetRequest added in v0.435.0

type FailChangesetRequest struct {

	// The changeset key to fail.
	Changeset string `protobuf:"bytes,1,opt,name=changeset,proto3" json:"changeset,omitempty"`
	// contains filtered or unexported fields
}

func (*FailChangesetRequest) Descriptor deprecated added in v0.435.0

func (*FailChangesetRequest) Descriptor() ([]byte, []int)

Deprecated: Use FailChangesetRequest.ProtoReflect.Descriptor instead.

func (*FailChangesetRequest) GetChangeset added in v0.435.0

func (x *FailChangesetRequest) GetChangeset() string

func (*FailChangesetRequest) ProtoMessage added in v0.435.0

func (*FailChangesetRequest) ProtoMessage()

func (*FailChangesetRequest) ProtoReflect added in v0.435.0

func (x *FailChangesetRequest) ProtoReflect() protoreflect.Message

func (*FailChangesetRequest) Reset added in v0.435.0

func (x *FailChangesetRequest) Reset()

func (*FailChangesetRequest) String added in v0.435.0

func (x *FailChangesetRequest) String() string

type FailChangesetResponse added in v0.435.0

type FailChangesetResponse struct {
	// contains filtered or unexported fields
}

func (*FailChangesetResponse) Descriptor deprecated added in v0.435.0

func (*FailChangesetResponse) Descriptor() ([]byte, []int)

Deprecated: Use FailChangesetResponse.ProtoReflect.Descriptor instead.

func (*FailChangesetResponse) ProtoMessage added in v0.435.0

func (*FailChangesetResponse) ProtoMessage()

func (*FailChangesetResponse) ProtoReflect added in v0.435.0

func (x *FailChangesetResponse) ProtoReflect() protoreflect.Message

func (*FailChangesetResponse) Reset added in v0.435.0

func (x *FailChangesetResponse) Reset()

func (*FailChangesetResponse) String added in v0.435.0

func (x *FailChangesetResponse) String() string

type FinalizeChangesetRequest added in v0.436.0

type FinalizeChangesetRequest struct {

	// The changeset key to commit.
	Changeset string `protobuf:"bytes,1,opt,name=changeset,proto3" json:"changeset,omitempty"`
	// contains filtered or unexported fields
}

func (*FinalizeChangesetRequest) Descriptor deprecated added in v0.436.0

func (*FinalizeChangesetRequest) Descriptor() ([]byte, []int)

Deprecated: Use FinalizeChangesetRequest.ProtoReflect.Descriptor instead.

func (*FinalizeChangesetRequest) GetChangeset added in v0.436.0

func (x *FinalizeChangesetRequest) GetChangeset() string

func (*FinalizeChangesetRequest) ProtoMessage added in v0.436.0

func (*FinalizeChangesetRequest) ProtoMessage()

func (*FinalizeChangesetRequest) ProtoReflect added in v0.436.0

func (x *FinalizeChangesetRequest) ProtoReflect() protoreflect.Message

func (*FinalizeChangesetRequest) Reset added in v0.436.0

func (x *FinalizeChangesetRequest) Reset()

func (*FinalizeChangesetRequest) String added in v0.436.0

func (x *FinalizeChangesetRequest) String() string

type FinalizeChangesetResponse added in v0.436.0

type FinalizeChangesetResponse struct {
	// contains filtered or unexported fields
}

func (*FinalizeChangesetResponse) Descriptor deprecated added in v0.436.0

func (*FinalizeChangesetResponse) Descriptor() ([]byte, []int)

Deprecated: Use FinalizeChangesetResponse.ProtoReflect.Descriptor instead.

func (*FinalizeChangesetResponse) ProtoMessage added in v0.436.0

func (*FinalizeChangesetResponse) ProtoMessage()

func (*FinalizeChangesetResponse) ProtoReflect added in v0.436.0

func (*FinalizeChangesetResponse) Reset added in v0.436.0

func (x *FinalizeChangesetResponse) Reset()

func (*FinalizeChangesetResponse) String added in v0.436.0

func (x *FinalizeChangesetResponse) String() string

type GetDeploymentContextRequest added in v0.448.0

type GetDeploymentContextRequest struct {
	Deployment string `protobuf:"bytes,1,opt,name=deployment,proto3" json:"deployment,omitempty"`
	// contains filtered or unexported fields
}

func (*GetDeploymentContextRequest) Descriptor deprecated added in v0.448.0

func (*GetDeploymentContextRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetDeploymentContextRequest.ProtoReflect.Descriptor instead.

func (*GetDeploymentContextRequest) GetDeployment added in v0.448.0

func (x *GetDeploymentContextRequest) GetDeployment() string

func (*GetDeploymentContextRequest) ProtoMessage added in v0.448.0

func (*GetDeploymentContextRequest) ProtoMessage()

func (*GetDeploymentContextRequest) ProtoReflect added in v0.448.0

func (*GetDeploymentContextRequest) Reset added in v0.448.0

func (x *GetDeploymentContextRequest) Reset()

func (*GetDeploymentContextRequest) String added in v0.448.0

func (x *GetDeploymentContextRequest) String() string

type GetDeploymentContextResponse added in v0.448.0

type GetDeploymentContextResponse struct {
	Module     string                                `protobuf:"bytes,1,opt,name=module,proto3" json:"module,omitempty"`
	Deployment string                                `protobuf:"bytes,2,opt,name=deployment,proto3" json:"deployment,omitempty"`
	Configs    map[string][]byte                     `` /* 141-byte string literal not displayed */
	Secrets    map[string][]byte                     `` /* 141-byte string literal not displayed */
	Databases  []*GetDeploymentContextResponse_DSN   `protobuf:"bytes,5,rep,name=databases,proto3" json:"databases,omitempty"`
	Routes     []*GetDeploymentContextResponse_Route `protobuf:"bytes,6,rep,name=routes,proto3" json:"routes,omitempty"`
	Egress     map[string]string                     `` /* 139-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*GetDeploymentContextResponse) Descriptor deprecated added in v0.448.0

func (*GetDeploymentContextResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetDeploymentContextResponse.ProtoReflect.Descriptor instead.

func (*GetDeploymentContextResponse) GetConfigs added in v0.448.0

func (x *GetDeploymentContextResponse) GetConfigs() map[string][]byte

func (*GetDeploymentContextResponse) GetDatabases added in v0.448.0

func (*GetDeploymentContextResponse) GetDeployment added in v0.448.0

func (x *GetDeploymentContextResponse) GetDeployment() string

func (*GetDeploymentContextResponse) GetEgress added in v0.477.0

func (x *GetDeploymentContextResponse) GetEgress() map[string]string

func (*GetDeploymentContextResponse) GetModule added in v0.448.0

func (x *GetDeploymentContextResponse) GetModule() string

func (*GetDeploymentContextResponse) GetRoutes added in v0.448.0

func (*GetDeploymentContextResponse) GetSecrets added in v0.448.0

func (x *GetDeploymentContextResponse) GetSecrets() map[string][]byte

func (*GetDeploymentContextResponse) ProtoMessage added in v0.448.0

func (*GetDeploymentContextResponse) ProtoMessage()

func (*GetDeploymentContextResponse) ProtoReflect added in v0.448.0

func (*GetDeploymentContextResponse) Reset added in v0.448.0

func (x *GetDeploymentContextResponse) Reset()

func (*GetDeploymentContextResponse) String added in v0.448.0

type GetDeploymentContextResponse_DSN added in v0.448.0

type GetDeploymentContextResponse_DSN struct {
	Name string                              `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	Type GetDeploymentContextResponse_DbType `protobuf:"varint,2,opt,name=type,proto3,enum=xyz.block.ftl.v1.GetDeploymentContextResponse_DbType" json:"type,omitempty"`
	Dsn  string                              `protobuf:"bytes,3,opt,name=dsn,proto3" json:"dsn,omitempty"`
	// contains filtered or unexported fields
}

func (*GetDeploymentContextResponse_DSN) Descriptor deprecated added in v0.448.0

func (*GetDeploymentContextResponse_DSN) Descriptor() ([]byte, []int)

Deprecated: Use GetDeploymentContextResponse_DSN.ProtoReflect.Descriptor instead.

func (*GetDeploymentContextResponse_DSN) GetDsn added in v0.448.0

func (*GetDeploymentContextResponse_DSN) GetName added in v0.448.0

func (*GetDeploymentContextResponse_DSN) GetType added in v0.448.0

func (*GetDeploymentContextResponse_DSN) ProtoMessage added in v0.448.0

func (*GetDeploymentContextResponse_DSN) ProtoMessage()

func (*GetDeploymentContextResponse_DSN) ProtoReflect added in v0.448.0

func (*GetDeploymentContextResponse_DSN) Reset added in v0.448.0

func (*GetDeploymentContextResponse_DSN) String added in v0.448.0

type GetDeploymentContextResponse_DbType added in v0.448.0

type GetDeploymentContextResponse_DbType int32
const (
	GetDeploymentContextResponse_DB_TYPE_UNSPECIFIED GetDeploymentContextResponse_DbType = 0
	GetDeploymentContextResponse_DB_TYPE_POSTGRES    GetDeploymentContextResponse_DbType = 1
	GetDeploymentContextResponse_DB_TYPE_MYSQL       GetDeploymentContextResponse_DbType = 2
)

func (GetDeploymentContextResponse_DbType) Descriptor added in v0.448.0

func (GetDeploymentContextResponse_DbType) Enum added in v0.448.0

func (GetDeploymentContextResponse_DbType) EnumDescriptor deprecated added in v0.448.0

func (GetDeploymentContextResponse_DbType) EnumDescriptor() ([]byte, []int)

Deprecated: Use GetDeploymentContextResponse_DbType.Descriptor instead.

func (GetDeploymentContextResponse_DbType) Number added in v0.448.0

func (GetDeploymentContextResponse_DbType) String added in v0.448.0

func (GetDeploymentContextResponse_DbType) Type added in v0.448.0

type GetDeploymentContextResponse_Route added in v0.448.0

type GetDeploymentContextResponse_Route struct {
	Deployment string `protobuf:"bytes,1,opt,name=deployment,proto3" json:"deployment,omitempty"`
	Uri        string `protobuf:"bytes,2,opt,name=uri,proto3" json:"uri,omitempty"`
	// contains filtered or unexported fields
}

func (*GetDeploymentContextResponse_Route) Descriptor deprecated added in v0.448.0

func (*GetDeploymentContextResponse_Route) Descriptor() ([]byte, []int)

Deprecated: Use GetDeploymentContextResponse_Route.ProtoReflect.Descriptor instead.

func (*GetDeploymentContextResponse_Route) GetDeployment added in v0.448.0

func (x *GetDeploymentContextResponse_Route) GetDeployment() string

func (*GetDeploymentContextResponse_Route) GetUri added in v0.448.0

func (*GetDeploymentContextResponse_Route) ProtoMessage added in v0.448.0

func (*GetDeploymentContextResponse_Route) ProtoMessage()

func (*GetDeploymentContextResponse_Route) ProtoReflect added in v0.448.0

func (*GetDeploymentContextResponse_Route) Reset added in v0.448.0

func (*GetDeploymentContextResponse_Route) String added in v0.448.0

type GetDeploymentRequest

type GetDeploymentRequest struct {
	DeploymentKey string `protobuf:"bytes,1,opt,name=deployment_key,json=deploymentKey,proto3" json:"deployment_key,omitempty"`
	// contains filtered or unexported fields
}

func (*GetDeploymentRequest) Descriptor deprecated

func (*GetDeploymentRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetDeploymentRequest.ProtoReflect.Descriptor instead.

func (*GetDeploymentRequest) GetDeploymentKey

func (x *GetDeploymentRequest) GetDeploymentKey() string

func (*GetDeploymentRequest) ProtoMessage

func (*GetDeploymentRequest) ProtoMessage()

func (*GetDeploymentRequest) ProtoReflect

func (x *GetDeploymentRequest) ProtoReflect() protoreflect.Message

func (*GetDeploymentRequest) Reset

func (x *GetDeploymentRequest) Reset()

func (*GetDeploymentRequest) String

func (x *GetDeploymentRequest) String() string

type GetDeploymentResponse

type GetDeploymentResponse struct {
	Schema *v1.Module `protobuf:"bytes,1,opt,name=schema,proto3" json:"schema,omitempty"`
	// contains filtered or unexported fields
}

func (*GetDeploymentResponse) Descriptor deprecated

func (*GetDeploymentResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetDeploymentResponse.ProtoReflect.Descriptor instead.

func (*GetDeploymentResponse) GetSchema

func (x *GetDeploymentResponse) GetSchema() *v1.Module

func (*GetDeploymentResponse) ProtoMessage

func (*GetDeploymentResponse) ProtoMessage()

func (*GetDeploymentResponse) ProtoReflect

func (x *GetDeploymentResponse) ProtoReflect() protoreflect.Message

func (*GetDeploymentResponse) Reset

func (x *GetDeploymentResponse) Reset()

func (*GetDeploymentResponse) String

func (x *GetDeploymentResponse) String() string

type GetDeploymentsRequest added in v0.434.0

type GetDeploymentsRequest struct {
	// contains filtered or unexported fields
}

func (*GetDeploymentsRequest) Descriptor deprecated added in v0.434.0

func (*GetDeploymentsRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetDeploymentsRequest.ProtoReflect.Descriptor instead.

func (*GetDeploymentsRequest) ProtoMessage added in v0.434.0

func (*GetDeploymentsRequest) ProtoMessage()

func (*GetDeploymentsRequest) ProtoReflect added in v0.434.0

func (x *GetDeploymentsRequest) ProtoReflect() protoreflect.Message

func (*GetDeploymentsRequest) Reset added in v0.434.0

func (x *GetDeploymentsRequest) Reset()

func (*GetDeploymentsRequest) String added in v0.434.0

func (x *GetDeploymentsRequest) String() string

type GetDeploymentsResponse added in v0.434.0

type GetDeploymentsResponse struct {
	Schema []*DeployedSchema `protobuf:"bytes,1,rep,name=schema,proto3" json:"schema,omitempty"`
	// contains filtered or unexported fields
}

func (*GetDeploymentsResponse) Descriptor deprecated added in v0.434.0

func (*GetDeploymentsResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetDeploymentsResponse.ProtoReflect.Descriptor instead.

func (*GetDeploymentsResponse) GetSchema added in v0.434.0

func (x *GetDeploymentsResponse) GetSchema() []*DeployedSchema

func (*GetDeploymentsResponse) ProtoMessage added in v0.434.0

func (*GetDeploymentsResponse) ProtoMessage()

func (*GetDeploymentsResponse) ProtoReflect added in v0.434.0

func (x *GetDeploymentsResponse) ProtoReflect() protoreflect.Message

func (*GetDeploymentsResponse) Reset added in v0.434.0

func (x *GetDeploymentsResponse) Reset()

func (*GetDeploymentsResponse) String added in v0.434.0

func (x *GetDeploymentsResponse) String() string

type GetSchemaRequest

type GetSchemaRequest struct {
	// contains filtered or unexported fields
}

func (*GetSchemaRequest) Descriptor deprecated

func (*GetSchemaRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetSchemaRequest.ProtoReflect.Descriptor instead.

func (*GetSchemaRequest) ProtoMessage

func (*GetSchemaRequest) ProtoMessage()

func (*GetSchemaRequest) ProtoReflect

func (x *GetSchemaRequest) ProtoReflect() protoreflect.Message

func (*GetSchemaRequest) Reset

func (x *GetSchemaRequest) Reset()

func (*GetSchemaRequest) String

func (x *GetSchemaRequest) String() string

type GetSchemaResponse

type GetSchemaResponse struct {
	Schema     *v1.Schema      `protobuf:"bytes,1,opt,name=schema,proto3" json:"schema,omitempty"`
	Changesets []*v1.Changeset `protobuf:"bytes,2,rep,name=changesets,proto3" json:"changesets,omitempty"`
	// contains filtered or unexported fields
}

func (*GetSchemaResponse) Descriptor deprecated

func (*GetSchemaResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetSchemaResponse.ProtoReflect.Descriptor instead.

func (*GetSchemaResponse) GetChangesets added in v0.435.0

func (x *GetSchemaResponse) GetChangesets() []*v1.Changeset

func (*GetSchemaResponse) GetSchema

func (x *GetSchemaResponse) GetSchema() *v1.Schema

func (*GetSchemaResponse) ProtoMessage

func (*GetSchemaResponse) ProtoMessage()

func (*GetSchemaResponse) ProtoReflect

func (x *GetSchemaResponse) ProtoReflect() protoreflect.Message

func (*GetSchemaResponse) Reset

func (x *GetSchemaResponse) Reset()

func (*GetSchemaResponse) String

func (x *GetSchemaResponse) String() string

type Metadata

type Metadata struct {
	Values []*Metadata_Pair `protobuf:"bytes,1,rep,name=values,proto3" json:"values,omitempty"`
	// contains filtered or unexported fields
}

func (*Metadata) Add

func (m *Metadata) Add(key, value string)

func (*Metadata) Delete

func (m *Metadata) Delete(key string)

func (*Metadata) Descriptor deprecated

func (*Metadata) Descriptor() ([]byte, []int)

Deprecated: Use Metadata.ProtoReflect.Descriptor instead.

func (*Metadata) Get

func (m *Metadata) Get(key string) optional.Option[string]

func (*Metadata) GetAll

func (m *Metadata) GetAll(key string) (out []string)

func (*Metadata) GetValues

func (x *Metadata) GetValues() []*Metadata_Pair

func (*Metadata) ProtoMessage

func (*Metadata) ProtoMessage()

func (*Metadata) ProtoReflect

func (x *Metadata) ProtoReflect() protoreflect.Message

func (*Metadata) Reset

func (x *Metadata) Reset()

func (*Metadata) Set

func (m *Metadata) Set(key, value string)

func (*Metadata) String

func (x *Metadata) String() string

type Metadata_Pair

type Metadata_Pair struct {
	Key   string `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
	Value string `protobuf:"bytes,2,opt,name=value,proto3" json:"value,omitempty"`
	// contains filtered or unexported fields
}

func (*Metadata_Pair) Descriptor deprecated

func (*Metadata_Pair) Descriptor() ([]byte, []int)

Deprecated: Use Metadata_Pair.ProtoReflect.Descriptor instead.

func (*Metadata_Pair) GetKey

func (x *Metadata_Pair) GetKey() string

func (*Metadata_Pair) GetValue

func (x *Metadata_Pair) GetValue() string

func (*Metadata_Pair) ProtoMessage

func (*Metadata_Pair) ProtoMessage()

func (*Metadata_Pair) ProtoReflect

func (x *Metadata_Pair) ProtoReflect() protoreflect.Message

func (*Metadata_Pair) Reset

func (x *Metadata_Pair) Reset()

func (*Metadata_Pair) String

func (x *Metadata_Pair) String() string

type PingRequest

type PingRequest struct {
	// contains filtered or unexported fields
}

func (*PingRequest) Descriptor deprecated

func (*PingRequest) Descriptor() ([]byte, []int)

Deprecated: Use PingRequest.ProtoReflect.Descriptor instead.

func (*PingRequest) ProtoMessage

func (*PingRequest) ProtoMessage()

func (*PingRequest) ProtoReflect

func (x *PingRequest) ProtoReflect() protoreflect.Message

func (*PingRequest) Reset

func (x *PingRequest) Reset()

func (*PingRequest) String

func (x *PingRequest) String() string

type PingResponse

type PingResponse struct {

	// If present, the service is not ready to accept requests and this is the
	// reason.
	NotReady *string `protobuf:"bytes,1,opt,name=not_ready,json=notReady,proto3,oneof" json:"not_ready,omitempty"`
	// contains filtered or unexported fields
}

func (*PingResponse) Descriptor deprecated

func (*PingResponse) Descriptor() ([]byte, []int)

Deprecated: Use PingResponse.ProtoReflect.Descriptor instead.

func (*PingResponse) GetNotReady

func (x *PingResponse) GetNotReady() string

func (*PingResponse) ProtoMessage

func (*PingResponse) ProtoMessage()

func (*PingResponse) ProtoReflect

func (x *PingResponse) ProtoReflect() protoreflect.Message

func (*PingResponse) Reset

func (x *PingResponse) Reset()

func (*PingResponse) String

func (x *PingResponse) String() string

type PrepareChangesetRequest added in v0.435.0

type PrepareChangesetRequest struct {

	// The changeset key to prepare.
	Changeset string `protobuf:"bytes,1,opt,name=changeset,proto3" json:"changeset,omitempty"`
	// contains filtered or unexported fields
}

func (*PrepareChangesetRequest) Descriptor deprecated added in v0.435.0

func (*PrepareChangesetRequest) Descriptor() ([]byte, []int)

Deprecated: Use PrepareChangesetRequest.ProtoReflect.Descriptor instead.

func (*PrepareChangesetRequest) GetChangeset added in v0.435.0

func (x *PrepareChangesetRequest) GetChangeset() string

func (*PrepareChangesetRequest) ProtoMessage added in v0.435.0

func (*PrepareChangesetRequest) ProtoMessage()

func (*PrepareChangesetRequest) ProtoReflect added in v0.435.0

func (x *PrepareChangesetRequest) ProtoReflect() protoreflect.Message

func (*PrepareChangesetRequest) Reset added in v0.435.0

func (x *PrepareChangesetRequest) Reset()

func (*PrepareChangesetRequest) String added in v0.435.0

func (x *PrepareChangesetRequest) String() string

type PrepareChangesetResponse added in v0.435.0

type PrepareChangesetResponse struct {
	// contains filtered or unexported fields
}

func (*PrepareChangesetResponse) Descriptor deprecated added in v0.435.0

func (*PrepareChangesetResponse) Descriptor() ([]byte, []int)

Deprecated: Use PrepareChangesetResponse.ProtoReflect.Descriptor instead.

func (*PrepareChangesetResponse) ProtoMessage added in v0.435.0

func (*PrepareChangesetResponse) ProtoMessage()

func (*PrepareChangesetResponse) ProtoReflect added in v0.435.0

func (x *PrepareChangesetResponse) ProtoReflect() protoreflect.Message

func (*PrepareChangesetResponse) Reset added in v0.435.0

func (x *PrepareChangesetResponse) Reset()

func (*PrepareChangesetResponse) String added in v0.435.0

func (x *PrepareChangesetResponse) String() string

type ProcessListRequest

type ProcessListRequest struct {
	// contains filtered or unexported fields
}

func (*ProcessListRequest) Descriptor deprecated

func (*ProcessListRequest) Descriptor() ([]byte, []int)

Deprecated: Use ProcessListRequest.ProtoReflect.Descriptor instead.

func (*ProcessListRequest) ProtoMessage

func (*ProcessListRequest) ProtoMessage()

func (*ProcessListRequest) ProtoReflect

func (x *ProcessListRequest) ProtoReflect() protoreflect.Message

func (*ProcessListRequest) Reset

func (x *ProcessListRequest) Reset()

func (*ProcessListRequest) String

func (x *ProcessListRequest) String() string

type ProcessListResponse

type ProcessListResponse struct {
	Processes []*ProcessListResponse_Process `protobuf:"bytes,1,rep,name=processes,proto3" json:"processes,omitempty"`
	// contains filtered or unexported fields
}

func (*ProcessListResponse) Descriptor deprecated

func (*ProcessListResponse) Descriptor() ([]byte, []int)

Deprecated: Use ProcessListResponse.ProtoReflect.Descriptor instead.

func (*ProcessListResponse) GetProcesses

func (x *ProcessListResponse) GetProcesses() []*ProcessListResponse_Process

func (*ProcessListResponse) ProtoMessage

func (*ProcessListResponse) ProtoMessage()

func (*ProcessListResponse) ProtoReflect

func (x *ProcessListResponse) ProtoReflect() protoreflect.Message

func (*ProcessListResponse) Reset

func (x *ProcessListResponse) Reset()

func (*ProcessListResponse) String

func (x *ProcessListResponse) String() string

type ProcessListResponse_Process

type ProcessListResponse_Process struct {
	Deployment  string                             `protobuf:"bytes,1,opt,name=deployment,proto3" json:"deployment,omitempty"`
	MinReplicas int32                              `protobuf:"varint,2,opt,name=min_replicas,json=minReplicas,proto3" json:"min_replicas,omitempty"`
	Labels      *structpb.Struct                   `protobuf:"bytes,3,opt,name=labels,proto3" json:"labels,omitempty"`
	Runner      *ProcessListResponse_ProcessRunner `protobuf:"bytes,4,opt,name=runner,proto3,oneof" json:"runner,omitempty"`
	// contains filtered or unexported fields
}

func (*ProcessListResponse_Process) Descriptor deprecated

func (*ProcessListResponse_Process) Descriptor() ([]byte, []int)

Deprecated: Use ProcessListResponse_Process.ProtoReflect.Descriptor instead.

func (*ProcessListResponse_Process) GetDeployment

func (x *ProcessListResponse_Process) GetDeployment() string

func (*ProcessListResponse_Process) GetLabels

func (*ProcessListResponse_Process) GetMinReplicas

func (x *ProcessListResponse_Process) GetMinReplicas() int32

func (*ProcessListResponse_Process) GetRunner

func (*ProcessListResponse_Process) ProtoMessage

func (*ProcessListResponse_Process) ProtoMessage()

func (*ProcessListResponse_Process) ProtoReflect

func (*ProcessListResponse_Process) Reset

func (x *ProcessListResponse_Process) Reset()

func (*ProcessListResponse_Process) String

func (x *ProcessListResponse_Process) String() string

type ProcessListResponse_ProcessRunner

type ProcessListResponse_ProcessRunner struct {
	Key      string           `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
	Endpoint string           `protobuf:"bytes,2,opt,name=endpoint,proto3" json:"endpoint,omitempty"`
	Labels   *structpb.Struct `protobuf:"bytes,3,opt,name=labels,proto3" json:"labels,omitempty"`
	// contains filtered or unexported fields
}

func (*ProcessListResponse_ProcessRunner) Descriptor deprecated

func (*ProcessListResponse_ProcessRunner) Descriptor() ([]byte, []int)

Deprecated: Use ProcessListResponse_ProcessRunner.ProtoReflect.Descriptor instead.

func (*ProcessListResponse_ProcessRunner) GetEndpoint

func (x *ProcessListResponse_ProcessRunner) GetEndpoint() string

func (*ProcessListResponse_ProcessRunner) GetKey

func (*ProcessListResponse_ProcessRunner) GetLabels

func (*ProcessListResponse_ProcessRunner) ProtoMessage

func (*ProcessListResponse_ProcessRunner) ProtoMessage()

func (*ProcessListResponse_ProcessRunner) ProtoReflect

func (*ProcessListResponse_ProcessRunner) Reset

func (*ProcessListResponse_ProcessRunner) String

type PullSchemaRequest

type PullSchemaRequest struct {
	SubscriptionId string `protobuf:"bytes,1,opt,name=subscription_id,json=subscriptionId,proto3" json:"subscription_id,omitempty"`
	// contains filtered or unexported fields
}

func (*PullSchemaRequest) Descriptor deprecated

func (*PullSchemaRequest) Descriptor() ([]byte, []int)

Deprecated: Use PullSchemaRequest.ProtoReflect.Descriptor instead.

func (*PullSchemaRequest) GetSubscriptionId added in v0.438.1

func (x *PullSchemaRequest) GetSubscriptionId() string

func (*PullSchemaRequest) ProtoMessage

func (*PullSchemaRequest) ProtoMessage()

func (*PullSchemaRequest) ProtoReflect

func (x *PullSchemaRequest) ProtoReflect() protoreflect.Message

func (*PullSchemaRequest) Reset

func (x *PullSchemaRequest) Reset()

func (*PullSchemaRequest) String

func (x *PullSchemaRequest) String() string

type PullSchemaResponse

type PullSchemaResponse struct {
	Event *v1.Notification `protobuf:"bytes,1,opt,name=event,proto3" json:"event,omitempty"`
	// contains filtered or unexported fields
}

func (*PullSchemaResponse) Descriptor deprecated

func (*PullSchemaResponse) Descriptor() ([]byte, []int)

Deprecated: Use PullSchemaResponse.ProtoReflect.Descriptor instead.

func (*PullSchemaResponse) GetEvent added in v0.435.0

func (x *PullSchemaResponse) GetEvent() *v1.Notification

func (*PullSchemaResponse) ProtoMessage

func (*PullSchemaResponse) ProtoMessage()

func (*PullSchemaResponse) ProtoReflect

func (x *PullSchemaResponse) ProtoReflect() protoreflect.Message

func (*PullSchemaResponse) Reset

func (x *PullSchemaResponse) Reset()

func (*PullSchemaResponse) String

func (x *PullSchemaResponse) String() string

type RealmChange added in v0.477.0

type RealmChange struct {
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// The modules to add or update.
	Modules []*v1.Module `protobuf:"bytes,2,rep,name=modules,proto3" json:"modules,omitempty"`
	// The deployments to remove.
	ToRemove []string `protobuf:"bytes,3,rep,name=to_remove,json=toRemove,proto3" json:"to_remove,omitempty"`
	// contains filtered or unexported fields
}

func (*RealmChange) Descriptor deprecated added in v0.477.0

func (*RealmChange) Descriptor() ([]byte, []int)

Deprecated: Use RealmChange.ProtoReflect.Descriptor instead.

func (*RealmChange) GetModules added in v0.477.0

func (x *RealmChange) GetModules() []*v1.Module

func (*RealmChange) GetName added in v0.477.0

func (x *RealmChange) GetName() string

func (*RealmChange) GetToRemove added in v0.477.0

func (x *RealmChange) GetToRemove() []string

func (*RealmChange) ProtoMessage added in v0.477.0

func (*RealmChange) ProtoMessage()

func (*RealmChange) ProtoReflect added in v0.477.0

func (x *RealmChange) ProtoReflect() protoreflect.Message

func (*RealmChange) Reset added in v0.477.0

func (x *RealmChange) Reset()

func (*RealmChange) String added in v0.477.0

func (x *RealmChange) String() string

type RegisterRunnerRequest

type RegisterRunnerRequest struct {
	Key        string           `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
	Endpoint   string           `protobuf:"bytes,2,opt,name=endpoint,proto3" json:"endpoint,omitempty"`
	Deployment string           `protobuf:"bytes,3,opt,name=deployment,proto3" json:"deployment,omitempty"`
	Labels     *structpb.Struct `protobuf:"bytes,5,opt,name=labels,proto3" json:"labels,omitempty"`
	// contains filtered or unexported fields
}

func (*RegisterRunnerRequest) Descriptor deprecated

func (*RegisterRunnerRequest) Descriptor() ([]byte, []int)

Deprecated: Use RegisterRunnerRequest.ProtoReflect.Descriptor instead.

func (*RegisterRunnerRequest) GetDeployment

func (x *RegisterRunnerRequest) GetDeployment() string

func (*RegisterRunnerRequest) GetEndpoint

func (x *RegisterRunnerRequest) GetEndpoint() string

func (*RegisterRunnerRequest) GetKey

func (x *RegisterRunnerRequest) GetKey() string

func (*RegisterRunnerRequest) GetLabels

func (x *RegisterRunnerRequest) GetLabels() *structpb.Struct

func (*RegisterRunnerRequest) ProtoMessage

func (*RegisterRunnerRequest) ProtoMessage()

func (*RegisterRunnerRequest) ProtoReflect

func (x *RegisterRunnerRequest) ProtoReflect() protoreflect.Message

func (*RegisterRunnerRequest) Reset

func (x *RegisterRunnerRequest) Reset()

func (*RegisterRunnerRequest) String

func (x *RegisterRunnerRequest) String() string

type RegisterRunnerResponse

type RegisterRunnerResponse struct {
	// contains filtered or unexported fields
}

func (*RegisterRunnerResponse) Descriptor deprecated

func (*RegisterRunnerResponse) Descriptor() ([]byte, []int)

Deprecated: Use RegisterRunnerResponse.ProtoReflect.Descriptor instead.

func (*RegisterRunnerResponse) ProtoMessage

func (*RegisterRunnerResponse) ProtoMessage()

func (*RegisterRunnerResponse) ProtoReflect

func (x *RegisterRunnerResponse) ProtoReflect() protoreflect.Message

func (*RegisterRunnerResponse) Reset

func (x *RegisterRunnerResponse) Reset()

func (*RegisterRunnerResponse) String

func (x *RegisterRunnerResponse) String() string

type RollbackChangesetRequest added in v0.442.0

type RollbackChangesetRequest struct {

	// The changeset key to fail.
	Changeset string `protobuf:"bytes,1,opt,name=changeset,proto3" json:"changeset,omitempty"`
	Error     string `protobuf:"bytes,2,opt,name=error,proto3" json:"error,omitempty"`
	// contains filtered or unexported fields
}

func (*RollbackChangesetRequest) Descriptor deprecated added in v0.442.0

func (*RollbackChangesetRequest) Descriptor() ([]byte, []int)

Deprecated: Use RollbackChangesetRequest.ProtoReflect.Descriptor instead.

func (*RollbackChangesetRequest) GetChangeset added in v0.442.0

func (x *RollbackChangesetRequest) GetChangeset() string

func (*RollbackChangesetRequest) GetError added in v0.442.0

func (x *RollbackChangesetRequest) GetError() string

func (*RollbackChangesetRequest) ProtoMessage added in v0.442.0

func (*RollbackChangesetRequest) ProtoMessage()

func (*RollbackChangesetRequest) ProtoReflect added in v0.442.0

func (x *RollbackChangesetRequest) ProtoReflect() protoreflect.Message

func (*RollbackChangesetRequest) Reset added in v0.442.0

func (x *RollbackChangesetRequest) Reset()

func (*RollbackChangesetRequest) String added in v0.442.0

func (x *RollbackChangesetRequest) String() string

type RollbackChangesetResponse added in v0.442.0

type RollbackChangesetResponse struct {
	Changeset *v1.Changeset `protobuf:"bytes,1,opt,name=changeset,proto3" json:"changeset,omitempty"`
	// contains filtered or unexported fields
}

func (*RollbackChangesetResponse) Descriptor deprecated added in v0.442.0

func (*RollbackChangesetResponse) Descriptor() ([]byte, []int)

Deprecated: Use RollbackChangesetResponse.ProtoReflect.Descriptor instead.

func (*RollbackChangesetResponse) GetChangeset added in v0.442.0

func (x *RollbackChangesetResponse) GetChangeset() *v1.Changeset

func (*RollbackChangesetResponse) ProtoMessage added in v0.442.0

func (*RollbackChangesetResponse) ProtoMessage()

func (*RollbackChangesetResponse) ProtoReflect added in v0.442.0

func (*RollbackChangesetResponse) Reset added in v0.442.0

func (x *RollbackChangesetResponse) Reset()

func (*RollbackChangesetResponse) String added in v0.442.0

func (x *RollbackChangesetResponse) String() string

type StatusRequest

type StatusRequest struct {
	// contains filtered or unexported fields
}

func (*StatusRequest) Descriptor deprecated

func (*StatusRequest) Descriptor() ([]byte, []int)

Deprecated: Use StatusRequest.ProtoReflect.Descriptor instead.

func (*StatusRequest) ProtoMessage

func (*StatusRequest) ProtoMessage()

func (*StatusRequest) ProtoReflect

func (x *StatusRequest) ProtoReflect() protoreflect.Message

func (*StatusRequest) Reset

func (x *StatusRequest) Reset()

func (*StatusRequest) String

func (x *StatusRequest) String() string

type StatusResponse

type StatusResponse struct {
	Controllers []*StatusResponse_Controller `protobuf:"bytes,1,rep,name=controllers,proto3" json:"controllers,omitempty"`
	Runners     []*StatusResponse_Runner     `protobuf:"bytes,2,rep,name=runners,proto3" json:"runners,omitempty"`
	Deployments []*StatusResponse_Deployment `protobuf:"bytes,3,rep,name=deployments,proto3" json:"deployments,omitempty"`
	Routes      []*StatusResponse_Route      `protobuf:"bytes,5,rep,name=routes,proto3" json:"routes,omitempty"`
	// contains filtered or unexported fields
}

func (*StatusResponse) Descriptor deprecated

func (*StatusResponse) Descriptor() ([]byte, []int)

Deprecated: Use StatusResponse.ProtoReflect.Descriptor instead.

func (*StatusResponse) GetControllers

func (x *StatusResponse) GetControllers() []*StatusResponse_Controller

func (*StatusResponse) GetDeployments

func (x *StatusResponse) GetDeployments() []*StatusResponse_Deployment

func (*StatusResponse) GetRoutes

func (x *StatusResponse) GetRoutes() []*StatusResponse_Route

func (*StatusResponse) GetRunners

func (x *StatusResponse) GetRunners() []*StatusResponse_Runner

func (*StatusResponse) ProtoMessage

func (*StatusResponse) ProtoMessage()

func (*StatusResponse) ProtoReflect

func (x *StatusResponse) ProtoReflect() protoreflect.Message

func (*StatusResponse) Reset

func (x *StatusResponse) Reset()

func (*StatusResponse) String

func (x *StatusResponse) String() string

type StatusResponse_Controller

type StatusResponse_Controller struct {
	Key      string `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
	Endpoint string `protobuf:"bytes,2,opt,name=endpoint,proto3" json:"endpoint,omitempty"`
	Version  string `protobuf:"bytes,3,opt,name=version,proto3" json:"version,omitempty"`
	// contains filtered or unexported fields
}

func (*StatusResponse_Controller) Descriptor deprecated

func (*StatusResponse_Controller) Descriptor() ([]byte, []int)

Deprecated: Use StatusResponse_Controller.ProtoReflect.Descriptor instead.

func (*StatusResponse_Controller) GetEndpoint

func (x *StatusResponse_Controller) GetEndpoint() string

func (*StatusResponse_Controller) GetKey

func (x *StatusResponse_Controller) GetKey() string

func (*StatusResponse_Controller) GetVersion

func (x *StatusResponse_Controller) GetVersion() string

func (*StatusResponse_Controller) ProtoMessage

func (*StatusResponse_Controller) ProtoMessage()

func (*StatusResponse_Controller) ProtoReflect

func (*StatusResponse_Controller) Reset

func (x *StatusResponse_Controller) Reset()

func (*StatusResponse_Controller) String

func (x *StatusResponse_Controller) String() string

type StatusResponse_Deployment

type StatusResponse_Deployment struct {
	Key         string           `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
	Language    string           `protobuf:"bytes,2,opt,name=language,proto3" json:"language,omitempty"`
	Name        string           `protobuf:"bytes,3,opt,name=name,proto3" json:"name,omitempty"`
	MinReplicas int32            `protobuf:"varint,4,opt,name=min_replicas,json=minReplicas,proto3" json:"min_replicas,omitempty"`
	Replicas    int32            `protobuf:"varint,7,opt,name=replicas,proto3" json:"replicas,omitempty"`
	Labels      *structpb.Struct `protobuf:"bytes,5,opt,name=labels,proto3" json:"labels,omitempty"`
	Schema      *v1.Module       `protobuf:"bytes,6,opt,name=schema,proto3" json:"schema,omitempty"`
	// contains filtered or unexported fields
}

func (*StatusResponse_Deployment) Descriptor deprecated

func (*StatusResponse_Deployment) Descriptor() ([]byte, []int)

Deprecated: Use StatusResponse_Deployment.ProtoReflect.Descriptor instead.

func (*StatusResponse_Deployment) GetKey

func (x *StatusResponse_Deployment) GetKey() string

func (*StatusResponse_Deployment) GetLabels

func (x *StatusResponse_Deployment) GetLabels() *structpb.Struct

func (*StatusResponse_Deployment) GetLanguage

func (x *StatusResponse_Deployment) GetLanguage() string

func (*StatusResponse_Deployment) GetMinReplicas

func (x *StatusResponse_Deployment) GetMinReplicas() int32

func (*StatusResponse_Deployment) GetName

func (x *StatusResponse_Deployment) GetName() string

func (*StatusResponse_Deployment) GetReplicas

func (x *StatusResponse_Deployment) GetReplicas() int32

func (*StatusResponse_Deployment) GetSchema

func (x *StatusResponse_Deployment) GetSchema() *v1.Module

func (*StatusResponse_Deployment) ProtoMessage

func (*StatusResponse_Deployment) ProtoMessage()

func (*StatusResponse_Deployment) ProtoReflect

func (*StatusResponse_Deployment) Reset

func (x *StatusResponse_Deployment) Reset()

func (*StatusResponse_Deployment) String

func (x *StatusResponse_Deployment) String() string

type StatusResponse_Route

type StatusResponse_Route struct {
	Module     string `protobuf:"bytes,1,opt,name=module,proto3" json:"module,omitempty"`
	Deployment string `protobuf:"bytes,2,opt,name=deployment,proto3" json:"deployment,omitempty"`
	Endpoint   string `protobuf:"bytes,3,opt,name=endpoint,proto3" json:"endpoint,omitempty"`
	// contains filtered or unexported fields
}

func (*StatusResponse_Route) Descriptor deprecated

func (*StatusResponse_Route) Descriptor() ([]byte, []int)

Deprecated: Use StatusResponse_Route.ProtoReflect.Descriptor instead.

func (*StatusResponse_Route) GetDeployment

func (x *StatusResponse_Route) GetDeployment() string

func (*StatusResponse_Route) GetEndpoint

func (x *StatusResponse_Route) GetEndpoint() string

func (*StatusResponse_Route) GetModule

func (x *StatusResponse_Route) GetModule() string

func (*StatusResponse_Route) ProtoMessage

func (*StatusResponse_Route) ProtoMessage()

func (*StatusResponse_Route) ProtoReflect

func (x *StatusResponse_Route) ProtoReflect() protoreflect.Message

func (*StatusResponse_Route) Reset

func (x *StatusResponse_Route) Reset()

func (*StatusResponse_Route) String

func (x *StatusResponse_Route) String() string

type StatusResponse_Runner

type StatusResponse_Runner struct {
	Key        string           `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
	Endpoint   string           `protobuf:"bytes,2,opt,name=endpoint,proto3" json:"endpoint,omitempty"`
	Deployment *string          `protobuf:"bytes,3,opt,name=deployment,proto3,oneof" json:"deployment,omitempty"`
	Labels     *structpb.Struct `protobuf:"bytes,4,opt,name=labels,proto3" json:"labels,omitempty"`
	// contains filtered or unexported fields
}

func (*StatusResponse_Runner) Descriptor deprecated

func (*StatusResponse_Runner) Descriptor() ([]byte, []int)

Deprecated: Use StatusResponse_Runner.ProtoReflect.Descriptor instead.

func (*StatusResponse_Runner) GetDeployment

func (x *StatusResponse_Runner) GetDeployment() string

func (*StatusResponse_Runner) GetEndpoint

func (x *StatusResponse_Runner) GetEndpoint() string

func (*StatusResponse_Runner) GetKey

func (x *StatusResponse_Runner) GetKey() string

func (*StatusResponse_Runner) GetLabels

func (x *StatusResponse_Runner) GetLabels() *structpb.Struct

func (*StatusResponse_Runner) ProtoMessage

func (*StatusResponse_Runner) ProtoMessage()

func (*StatusResponse_Runner) ProtoReflect

func (x *StatusResponse_Runner) ProtoReflect() protoreflect.Message

func (*StatusResponse_Runner) Reset

func (x *StatusResponse_Runner) Reset()

func (*StatusResponse_Runner) String

func (x *StatusResponse_Runner) String() string

type UpdateDeploymentRuntimeRequest

type UpdateDeploymentRuntimeRequest struct {
	Changeset *string            `protobuf:"bytes,1,opt,name=changeset,proto3,oneof" json:"changeset,omitempty"`
	Update    *v1.RuntimeElement `protobuf:"bytes,2,opt,name=update,proto3" json:"update,omitempty"`
	// contains filtered or unexported fields
}

func (*UpdateDeploymentRuntimeRequest) Descriptor deprecated

func (*UpdateDeploymentRuntimeRequest) Descriptor() ([]byte, []int)

Deprecated: Use UpdateDeploymentRuntimeRequest.ProtoReflect.Descriptor instead.

func (*UpdateDeploymentRuntimeRequest) GetChangeset added in v0.439.0

func (x *UpdateDeploymentRuntimeRequest) GetChangeset() string

func (*UpdateDeploymentRuntimeRequest) GetUpdate added in v0.439.0

func (*UpdateDeploymentRuntimeRequest) ProtoMessage

func (*UpdateDeploymentRuntimeRequest) ProtoMessage()

func (*UpdateDeploymentRuntimeRequest) ProtoReflect

func (*UpdateDeploymentRuntimeRequest) Reset

func (x *UpdateDeploymentRuntimeRequest) Reset()

func (*UpdateDeploymentRuntimeRequest) String

type UpdateDeploymentRuntimeResponse

type UpdateDeploymentRuntimeResponse struct {
	// contains filtered or unexported fields
}

func (*UpdateDeploymentRuntimeResponse) Descriptor deprecated

func (*UpdateDeploymentRuntimeResponse) Descriptor() ([]byte, []int)

Deprecated: Use UpdateDeploymentRuntimeResponse.ProtoReflect.Descriptor instead.

func (*UpdateDeploymentRuntimeResponse) ProtoMessage

func (*UpdateDeploymentRuntimeResponse) ProtoMessage()

func (*UpdateDeploymentRuntimeResponse) ProtoReflect

func (*UpdateDeploymentRuntimeResponse) Reset

func (*UpdateDeploymentRuntimeResponse) String

Directories

Path Synopsis

Jump to